queue

package
v1.50.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 5, 2026 License: MIT Imports: 0 Imported by: 0

Documentation

Overview

Package queue is a generic FIFO ring buffer adapted from github.com/eapache/queue. It is not safe for concurrent use.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Queue

type Queue[T any] struct {
	// contains filtered or unexported fields
}

Queue is a generic FIFO ring buffer. The zero value is an empty queue ready for use.

func (*Queue[T]) Add

func (q *Queue[T]) Add(elem T)

Add appends elem, growing the buffer if it is full.

func (*Queue[T]) Length

func (q *Queue[T]) Length() int

Length returns the number of elements in the queue.

func (*Queue[T]) Peek

func (q *Queue[T]) Peek() T

Peek returns the head element. It panics if the queue is empty.

func (*Queue[T]) Remove

func (q *Queue[T]) Remove() T

Remove pops and returns the head element. It panics if the queue is empty.

Jump to